package javax.xml.datatype;

import java.util.Locale;
import java.util.TimeZone;
import java.util.GregorianCalendar;
import javax.xml.namespace.QName;
import java.math.BigDecimal;
import java.math.BigInteger;

public abstract class XMLGregorianCalendar implements Cloneable
{
    public XMLGregorianCalendar() {
    }
    
    public abstract void clear();
    
    public abstract void reset();
    
    public abstract void setYear(BigInteger p0);
    
    public abstract void setYear(int p0);
    
    public abstract void setMonth(int p0);
    
    public abstract void setDay(int p0);
    
    public abstract void setTimezone(int p0);
    
    public void setTime(int hour, int minute, int second) {
        this.setTime(hour, minute, second, null);
    }
    
    public abstract void setHour(int p0);
    
    public abstract void setMinute(int p0);
    
    public abstract void setSecond(int p0);
    
    public abstract void setMillisecond(int p0);
    
    public abstract void setFractionalSecond(BigDecimal p0);
    
    public void setTime(int hour, int minute, int second, BigDecimal fractional) {
        this.setHour(hour);
        this.setMinute(minute);
        this.setSecond(second);
        this.setFractionalSecond(fractional);
    }
    
    public void setTime(int hour, int minute, int second, int millisecond) {
        this.setHour(hour);
        this.setMinute(minute);
        this.setSecond(second);
        this.setMillisecond(millisecond);
    }
    
    public abstract BigInteger getEon();
    
    public abstract int getYear();
    
    public abstract BigInteger getEonAndYear();
    
    public abstract int getMonth();
    
    public abstract int getDay();
    
    public abstract int getTimezone();
    
    public abstract int getHour();
    
    public abstract int getMinute();
    
    public abstract int getSecond();
    
    public int getMillisecond() {
        BigDecimal fractionalSeconds = this.getFractionalSecond();
        if (fractionalSeconds == null) {
            return Integer.MIN_VALUE;
        }
        return this.getFractionalSecond().movePointRight(3).intValue();
    }
    
    public abstract BigDecimal getFractionalSecond();
    
    public abstract int compare(XMLGregorianCalendar p0);
    
    public abstract XMLGregorianCalendar normalize();
    
    @Override
    public boolean equals(Object obj) {
        return obj != null && obj instanceof XMLGregorianCalendar && this.compare((XMLGregorianCalendar)obj) == 0;
    }
    
    @Override
    public int hashCode() {
        int timezone = this.getTimezone();
        if (timezone == Integer.MIN_VALUE) {
            timezone = 0;
        }
        XMLGregorianCalendar gc = this;
        if (timezone != 0) {
            gc = this.normalize();
        }
        return gc.getYear() + gc.getMonth() + gc.getDay() + gc.getHour() + gc.getMinute() + gc.getSecond();
    }
    
    public abstract String toXMLFormat();
    
    public abstract QName getXMLSchemaType();
    
    @Override
    public String toString() {
        return this.toXMLFormat();
    }
    
    public abstract boolean isValid();
    
    public abstract void add(Duration p0);
    
    public abstract GregorianCalendar toGregorianCalendar();
    
    public abstract GregorianCalendar toGregorianCalendar(TimeZone p0, Locale p1, XMLGregorianCalendar p2);
    
    public abstract TimeZone getTimeZone(int p0);
    
    public abstract Object clone();
}
